"use strict";
const command_1 = require("@oclif/command");
const _1 = require(".");
class Gsej extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Gsej);
        const config = {
            clientId: flags.clientId,
            clientSecret: flags.clientSecret,
            accessToken: flags.accessToken,
            refreshToken: flags.refreshToken,
        };
        try {
            const result = await _1.exportJson(args.spreadsheet_id, args.sheet_title, config);
            this.log(JSON.stringify(result));
        }
        catch (e) {
            this.error(e, {
                suggestions: [
                    'create .env file, (try our helper: https://github.com/vdelacou/iblis-cli-token-google-oauth-web-server)',
                    'add options --clientId=clientId --clientSecret=clientSecret --accessToken=accessToken --refreshToken=refreshToken',
                ],
                ref: 'https://github.com/vdelacou/google-sheets-export-json#readme',
            });
        }
    }
}
Gsej.description = 'Export Google Sheets to JSON';
Gsej.flags = {
    version: command_1.flags.version({ char: 'v' }),
    help: command_1.flags.help({ char: 'h' }),
    clientId: command_1.flags.string({ description: 'Google OAuth client id' }),
    clientSecret: command_1.flags.string({ description: 'Google OAuth client secret' }),
    accessToken: command_1.flags.string({ description: 'Google OAuth access token' }),
    refreshToken: command_1.flags.string({ description: 'Google OAuth refresh token' }),
};
Gsej.args = [
    { name: 'spreadsheet_id', description: 'Google SpreadSheet Id', required: true },
    { name: 'sheet_title', description: 'Sheet Title', required: true },
];
module.exports = Gsej;
