"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findSheetByTitle = void 0;
const error_code_1 = require("../../error_code");
/**
 * Find the sheet among a list of sheets by title
 *
 * @param sheets a list of sheets
 * @param sheetTitle the title to find
 *
 * @returns the sheet with title
 *
 * @throws {SHEET_TITLE_NOT_FOUND} if cannot find a sheet with the title
 */
const findSheetByTitle = (sheets, sheetTitle) => {
    const sheet = sheets.find((value) => {
        if (!value.properties) {
            return false;
        }
        return value.properties.title === sheetTitle;
    });
    if (!sheet) {
        throw new Error(error_code_1.SHEET_TITLE_NOT_FOUND);
    }
    return sheet;
};
exports.findSheetByTitle = findSheetByTitle;
