"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGoogleSheetClient = void 0;
const googleapis_1 = require("googleapis");
const googleapis_common_1 = require("googleapis-common");
const error_code_1 = require("../../error_code");
/**
 * Get the google sheet client, need have environement variable GOOGLE_CLIENT_ID GOOGLE_CLIENT_SECRET GOOGLE_ACCESS_TOKEN GOOGLE_REFRESH_TOKEN
 *
 * @throws NO_GOOGLE_ACCESS_TOKEN NO_GOOGLE_CLIENT_ID NO_GOOGLE_CLIENT_SECRET NO_GOOGLE_REFRESH_TOKEN
 */
const getGoogleSheetClient = () => {
    if (!process.env.GOOGLE_CLIENT_ID) {
        throw new Error(error_code_1.NO_GOOGLE_CLIENT_ID);
    }
    if (!process.env.GOOGLE_CLIENT_SECRET) {
        throw new Error(error_code_1.NO_GOOGLE_CLIENT_SECRET);
    }
    if (!process.env.GOOGLE_ACCESS_TOKEN) {
        throw new Error(error_code_1.NO_GOOGLE_ACCESS_TOKEN);
    }
    if (!process.env.GOOGLE_REFRESH_TOKEN) {
        throw new Error(error_code_1.NO_GOOGLE_REFRESH_TOKEN);
    }
    const oAuth2Client = new googleapis_common_1.OAuth2Client(process.env.GOOGLE_CLIENT_ID, process.env.GOOGLE_CLIENT_SECRET);
    oAuth2Client.credentials = { access_token: process.env.GOOGLE_ACCESS_TOKEN, refresh_token: process.env.GOOGLE_REFRESH_TOKEN };
    const sheetClient = googleapis_1.google.sheets({ version: 'v4', auth: oAuth2Client });
    return sheetClient;
};
exports.getGoogleSheetClient = getGoogleSheetClient;
