"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSheetData = void 0;
const error_code_1 = require("../../error_code");
const find_sheet_by_title_1 = require("../find_sheet_by_title");
/**
 * Get the data from the sheets and check if the first row have the KEYS_VALUE, so it means that the spreadsheet use the JSON Noob format
 *
 * @throws {FIRST_CELL_NOT_KEY}
 * @throws {FIRST_ROW_NOT_FOUND}
 * @throws {KEYS_VALUE}
 * @throws {SHEET_DATA_NOT_FOUND}
 * @throws {SHEET_GRID_DATA_NOT_FOUND}
 * @throws {SHEET_TITLE_NOT_FOUND}
 */
const getSheetData = async (sheetClient, spreadsheetId, sheetTitle) => {
    const spreadsheet = await sheetClient.spreadsheets.get({
        includeGridData: true,
        spreadsheetId,
    });
    if (!spreadsheet.data.sheets) {
        throw new Error(error_code_1.SHEET_DATA_NOT_FOUND);
    }
    const sheet = find_sheet_by_title_1.findSheetByTitle(spreadsheet.data.sheets, sheetTitle);
    // check if we have first row
    const { data } = sheet;
    if (!data || !data[0]) {
        throw new Error(error_code_1.SHEET_GRID_DATA_NOT_FOUND);
    }
    if (!data[0].rowData || !data[0].rowData[0]) {
        throw new Error(error_code_1.FIRST_ROW_NOT_FOUND);
    }
    return data[0];
};
exports.getSheetData = getSheetData;
