"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkConfig = exports.exportJson = void 0;
// import { getGoogleSheetClient } from './google_sheet_utils/google_sheet_client';
// (async () => {
//   log.info('Start');
//   const sheetClient = getGoogleSheetClient();
//   const spreadsheet = await sheetClient.spreadsheets.get({
//     includeGridData: true,
//     spreadsheetId: '1Q0wGZ1rMdbl8i6EwdKYNgE1H-JyFqI2X2TenjtPaOqQ',
//   });
//   console.log(JSON.stringify(spreadsheet.data.sheets));
//   log.info(`End`);
// })().catch((e) => {
//   log.error(e);
// });
const dotenv_1 = __importDefault(require("dotenv"));
const googleapis_1 = require("googleapis");
const googleapis_common_1 = require("googleapis-common");
const error_code_1 = require("./error_code");
const extract_data_array_1 = require("./google_sheet_utils/extract_data_array");
const google_sheet_data_1 = require("./google_sheet_utils/google_sheet_data");
dotenv_1.default.config();
const exportJson = async (spreadsheet_id, sheetTitle, configInput) => {
    // check config
    const config = exports.checkConfig(configInput);
    // get google sheet api
    const oAuth2Client = new googleapis_common_1.OAuth2Client(config.clientId, config.clientSecret);
    oAuth2Client.credentials = { access_token: config.accessToken, refresh_token: config.refreshToken };
    const googleSheetApi = googleapis_1.google.sheets({ version: 'v4', auth: oAuth2Client });
    // get data
    const data = await google_sheet_data_1.getSheetData(googleSheetApi, spreadsheet_id, sheetTitle);
    const result = extract_data_array_1.extractDataArray(data);
    return result;
};
exports.exportJson = exportJson;
/**
 * Check if we have correct config to setup google client and access to the sheet
 *
 * @throws {NO_GOOGLE_CLIENT_ID}
 * @throws {NO_GOOGLE_CLIENT_SECRET}
 * @throws {NO_GOOGLE_ACCESS_TOKEN}
 * @throws {NO_GOOGLE_REFRESH_TOKEN}
 */
const checkConfig = (config) => {
    let clientId = process.env.GOOGLE_CLIENT_ID;
    if (config && config.clientId) {
        clientId = config.clientId;
    }
    if (!clientId) {
        throw new Error(error_code_1.NO_GOOGLE_CLIENT_ID);
    }
    let clientSecret = process.env.GOOGLE_CLIENT_SECRET;
    if (config && config.clientSecret) {
        clientSecret = config.clientSecret;
    }
    if (!clientSecret) {
        throw new Error(error_code_1.NO_GOOGLE_CLIENT_SECRET);
    }
    let accessToken = process.env.GOOGLE_ACCESS_TOKEN;
    if (config && config.accessToken) {
        accessToken = config.accessToken;
    }
    if (!accessToken) {
        throw new Error(error_code_1.NO_GOOGLE_ACCESS_TOKEN);
    }
    let refreshToken = process.env.GOOGLE_REFRESH_TOKEN;
    if (config && config.refreshToken) {
        refreshToken = config.refreshToken;
    }
    if (!refreshToken) {
        throw new Error(error_code_1.NO_GOOGLE_REFRESH_TOKEN);
    }
    return {
        clientId,
        clientSecret,
        accessToken,
        refreshToken,
    };
};
exports.checkConfig = checkConfig;
